#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-pandoc
version:              0.2.1
visibility:           public
id:                   commonmark-pandoc-0.2.1-7jx7EVhtSfP51SKvQsSGJJ
key:                  commonmark-pandoc-0.2.1-7jx7EVhtSfP51SKvQsSGJJ
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  e39a8584465b5176f6a126290a598672
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-8.10.5/site-local/commonmark-pandoc-0.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/commonmark-pandoc-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/commonmark-pandoc-0.2.1
hs-libraries:         HScommonmark-pandoc-0.2.1-7jx7EVhtSfP51SKvQsSGJJ
depends:
    base-4.14.2.0 commonmark-0.2-AFP3X37kEnxFrTX9FSUNYE
    commonmark-extensions-0.2.1.2-AUPICgxZ8l6JaoePRpaYCj
    pandoc-types-1.22-EryfWWHRfW5KncHtOPy01K text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

